"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsBigInt = exports.IS_BIGINT = void 0;
const class_validator_1 = require("class-validator");
const is_bigint_predicate_1 = require("./is-bigint.predicate");
/** @hidden */
exports.IS_BIGINT = 'isBigInt';
/**
 * Checks if the given value is a [BigInt](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/BigInt).
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a BigInt.
 * @IsBigInt()
 * hugeNumber: BigInt
 * ```
 *
 * @category Type
 * @param options Generic class-validator options.
 */
function IsBigInt(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.IS_BIGINT,
        validator: {
            validate: (value, _arguments) => (0, is_bigint_predicate_1.isBigInt)(value),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must be a BigInt`, options),
        },
    }, options);
}
exports.IsBigInt = IsBigInt;
