import type { ValidationOptions } from 'class-validator';
/** @hidden */
export declare const MIN_BIGINT = "minBigInt";
/**
 * Checks if the given value is a [BigInt](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/BigInt)
 * not less than `minimum`.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is greater than 9000.
 * @MinBigInt(9_001)
 * overNineThousand: BigInt
 * ```
 *
 * @category BigInt
 * @param minimum The minimum allowed value.
 * @param options Generic class-validator options.
 */
export declare function MinBigInt(minimum: number | bigint, options?: ValidationOptions): PropertyDecorator;
