"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Nullable = void 0;
const class_validator_1 = require("class-validator");
/**
 * Only validates the given value if it is not `null`.
 *
 * This is similar to the built-in `@IsOptional` except that it does not allow `undefined`. Note that this validator
 * does not work as expected with `{ each: true }` (because it is based on `@ValidateIf` which does not either).
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a string or null (but not undefined).
 * @Nullable()
 * @IsString()
 * value: string | null
 * ```
 *
 * @category Common
 * @param options Generic class-validator options.
 */
function Nullable(options) {
    // eslint-disable-next-line @typescript-eslint/ban-types
    return function nullableDecorator(prototype, propertyKey) {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
        (0, class_validator_1.ValidateIf)(object => object[propertyKey] !== null, options)(prototype, propertyKey);
    };
}
exports.Nullable = Nullable;
