"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Optional = void 0;
const class_validator_1 = require("class-validator");
/**
 * Only validates the given value if it is not `undefined`.
 *
 * This is similar to the built-in `@IsOptional` except that it does not allow `null`. Note that this validator does not
 * work as expected with `{ each: true }` (because it is based on `@ValidateIf` which does not either).
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a string or undefined (but not null).
 * @Optional()
 * @IsString()
 * value?: string
 * ```
 *
 * @category Common
 * @param options Generic class-validator options.
 */
function Optional(options) {
    // eslint-disable-next-line @typescript-eslint/ban-types
    return function optionalDecorator(prototype, propertyKey) {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
        (0, class_validator_1.ValidateIf)(object => object[propertyKey] !== undefined, options)(prototype, propertyKey);
    };
}
exports.Optional = Optional;
