import type { ValidationOptions } from 'class-validator';
/** @hidden */
export declare const IS_DAYJS = "isDayjs";
/**
 * Checks if the given value is a valid Dayjs object.
 *
 * Note that `dayjs` is not a constructor, so you can't simply use `@IsInstance(Dayjs)`.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a Dayjs object.
 * @IsDayjs()
 * dateOfBirth: Dayjs
 * ```
 *
 * @category Type
 * @param options
 * Accepts the following options (in addition to generic class-validator options):
 *   - `allow_invalid: boolean = false`
 *     If true, allow the Dayjs object to be invalid (see [isValid()](https://day.js.org/docs/en/parse/is-valid)).
 */
export declare function IsDayjs(options?: {
    allow_invalid?: boolean;
} & ValidationOptions): PropertyDecorator;
