"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsDayjs = exports.IS_DAYJS = void 0;
const class_validator_1 = require("class-validator");
const is_dayjs_predicate_1 = require("./is-dayjs.predicate");
/** @hidden */
exports.IS_DAYJS = 'isDayjs';
/**
 * Checks if the given value is a valid Dayjs object.
 *
 * Note that `dayjs` is not a constructor, so you can't simply use `@IsInstance(Dayjs)`.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a Dayjs object.
 * @IsDayjs()
 * dateOfBirth: Dayjs
 * ```
 *
 * @category Type
 * @param options
 * Accepts the following options (in addition to generic class-validator options):
 *   - `allow_invalid: boolean = false`
 *     If true, allow the Dayjs object to be invalid (see [isValid()](https://day.js.org/docs/en/parse/is-valid)).
 */
function IsDayjs(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.IS_DAYJS,
        validator: {
            validate: (value, _arguments) => (0, is_dayjs_predicate_1.isDayjs)(value, { allow_invalid: options === null || options === void 0 ? void 0 : options.allow_invalid }),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must be ${(options === null || options === void 0 ? void 0 : options.allow_invalid) ? 'a' : 'a valid'} Dayjs object`, options),
        },
    }, options);
}
exports.IsDayjs = IsDayjs;
