import type { ValidationOptions } from 'class-validator';
/** @hidden */
export declare const IS_DURATION = "isDuration";
/**
 * Checks if the given value is a valid Dayjs duration.
 *
 * A duration is considered valid if and only if:
 *   - it passes [dayjs.isDuration()](https://day.js.org/docs/en/durations/is-a-duration)
 *   - its numeric value is a finite number (i.e., `duration.asMilliseconds()` is not `NaN`)
 *   - its numeric value is non-negative
 *
 * This requires the [duration-plugin](https://day.js.org/docs/en/plugin/duration) to be loaded. If this is not the
 * case, an error will be thrown.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a Dayjs duration.
 * @IsDuration()
 * value: Duration
 * ```
 *
 * @category Type
 * @param options
 * Accepts the following options (in addition to generic class-validator options):
 *   - `allow_invalid: boolean = false`
 *     If true, allow the duration to be invalid.
 */
export declare function IsDuration(options?: {
    allow_invalid?: boolean;
} & ValidationOptions): PropertyDecorator;
