import type { ValidationOptions } from 'class-validator';
/** @hidden */
export declare const IS_MAP = "isMap";
/**
 * Checks if the given value is a [Map](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Map).
 *
 * This is a convenience decorator for `@IsInstance(Map)`.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a Map.
 * @IsMap()
 * values: Map<string, string>
 * ```
 *
 * @category Type
 * @param options Generic class-validator options.
 */
export declare function IsMap(options?: ValidationOptions): PropertyDecorator;
