"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsMap = exports.IS_MAP = void 0;
const class_validator_1 = require("class-validator");
const is_map_predicate_1 = require("./is-map.predicate");
/** @hidden */
exports.IS_MAP = 'isMap';
/**
 * Checks if the given value is a [Map](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Map).
 *
 * This is a convenience decorator for `@IsInstance(Map)`.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a Map.
 * @IsMap()
 * values: Map<string, string>
 * ```
 *
 * @category Type
 * @param options Generic class-validator options.
 */
function IsMap(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.IS_MAP,
        validator: {
            validate: (value, _arguments) => (0, is_map_predicate_1.isMap)(value),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must be an instance of Map`, options),
        },
    }, options);
}
exports.IsMap = IsMap;
