"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MapNotEmpty = exports.MAP_NOT_EMPTY = void 0;
const class_validator_1 = require("class-validator");
const map_not_empty_predicate_1 = require("./map-not-empty.predicate");
/** @hidden */
exports.MAP_NOT_EMPTY = 'mapNotEmpty';
/**
 * Checks if the given value is a [Map](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Map)
 * with at least one entry.
 *
 * #### Example
 * ```typescript
 * // Ensure the map is not empty.
 * @MapNotEmpty()
 * values: Map
 * ```
 *
 * @category Map
 * @param options Generic class-validator options.
 */
function MapNotEmpty(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.MAP_NOT_EMPTY,
        validator: {
            validate: (value, _arguments) => (0, map_not_empty_predicate_1.mapNotEmpty)(value),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must not be an empty map`, options),
        },
    }, options);
}
exports.MapNotEmpty = MapNotEmpty;
