import type { ValidationOptions } from 'class-validator';
/** @hidden */
export declare const IS_SET = "isSet";
/**
 * Checks if the given value is a [Set](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Set).
 *
 * This is a convenience decorator for `@IsInstance(Set)`.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a Set.
 * @IsSet()
 * values: Set<string>
 * ```
 *
 * @category Type
 * @param options Generic class-validator options.
 */
export declare function IsSet(options?: ValidationOptions): PropertyDecorator;
