"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsSet = exports.IS_SET = void 0;
const class_validator_1 = require("class-validator");
const is_set_predicate_1 = require("./is-set.predicate");
/** @hidden */
exports.IS_SET = 'isSet';
/**
 * Checks if the given value is a [Set](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Set).
 *
 * This is a convenience decorator for `@IsInstance(Set)`.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a Set.
 * @IsSet()
 * values: Set<string>
 * ```
 *
 * @category Type
 * @param options Generic class-validator options.
 */
function IsSet(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.IS_SET,
        validator: {
            validate: (value, _arguments) => (0, is_set_predicate_1.isSet)(value),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must be an instance of Set`, options),
        },
    }, options);
}
exports.IsSet = IsSet;
