"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetContains = exports.SET_CONTAINS = void 0;
const class_validator_1 = require("class-validator");
const set_contains_predicate_1 = require("./set-contains.predicate");
/** @hidden */
exports.SET_CONTAINS = 'setContains';
/**
 * Checks if the given value is a [Set](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Set)
 * and contains all required values.
 *
 * #### Example
 * ```typescript
 * // Ensure the set contains (at least) 'foo' and 'bar'.
 * @SetContains(['foo', 'bar'])
 * values: Set<string>
 * ```
 *
 * @category Set
 * @param required The values required in the given set.
 * @param options Generic class-validator options.
 * @typeParam Value The type of values to check for.
 */
function SetContains(required, options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.SET_CONTAINS,
        validator: {
            validate: (value, _arguments) => (0, set_contains_predicate_1.setContains)(value, required),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must contain all of the following values: ${[...required].join(', ')}`, options),
        },
    }, options);
}
exports.SetContains = SetContains;
