"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetNotEmpty = exports.SET_NOT_EMPTY = void 0;
const class_validator_1 = require("class-validator");
const set_not_empty_predicate_1 = require("./set-not-empty.predicate");
/** @hidden */
exports.SET_NOT_EMPTY = 'setNotEmpty';
/**
 * Checks if the given value is a [Set](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Set)
 * with at least one value.
 *
 * #### Example
 * ```typescript
 * // Ensure the set is not empty.
 * @SetNotEmpty()
 * values: Set<string>
 * ```
 *
 * @category Set
 * @param options Generic class-validator options.
 */
function SetNotEmpty(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.SET_NOT_EMPTY,
        validator: {
            validate: (value, _arguments) => (0, set_not_empty_predicate_1.setNotEmpty)(value),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must not be an empty set`, options),
        },
    }, options);
}
exports.SetNotEmpty = SetNotEmpty;
