"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IsTimezone = exports.IS_TIMEZONE = void 0;
const class_validator_1 = require("class-validator");
const is_timezone_predicate_1 = require("./is-timezone.predicate");
/** @hidden */
exports.IS_TIMEZONE = 'isTimezone';
/**
 * Checks if the given value is a valid timezone string.
 *
 * Uses [Intl](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl) internally for
 * validation.
 *
 * #### Example
 * ```typescript
 * // Ensure the value is a valid timezone.
 * @IsTimezone()
 * timezone: string = 'Pacific/Guam'
 * ```
 *
 * @category String
 * @param options Generic class-validator options.
 */
function IsTimezone(options) {
    return (0, class_validator_1.ValidateBy)({
        name: exports.IS_TIMEZONE,
        validator: {
            validate: (value, _arguments) => (0, is_timezone_predicate_1.isTimezone)(value),
            defaultMessage: (0, class_validator_1.buildMessage)(eachPrefix => `${eachPrefix}$property must be a timezone string`, options),
        },
    }, options);
}
exports.IsTimezone = IsTimezone;
